# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
from .. import _utilities
from . import outputs

__all__ = [
    'ProvisionedProductOutput',
    'ProvisionedProductParameter',
    'GetEndUserProductsEndUserProductResult',
    'GetLaunchOptionsLaunchOptionResult',
    'GetLaunchOptionsLaunchOptionConstraintSummaryResult',
    'GetLaunchOptionsOptionResult',
    'GetLaunchOptionsOptionConstraintSummaryResult',
    'GetPortfoliosPortfolioResult',
    'GetProductAsEndUsersUserResult',
    'GetProductVersionsProductVersionResult',
    'GetProductVersionsVersionResult',
    'GetProvisionedProductsProductResult',
    'GetProvisionedProductsProductOutputResult',
    'GetProvisionedProductsProductParameterResult',
    'GetProvisionedProductsProvisionedProductResult',
    'GetProvisionedProductsProvisionedProductOutputResult',
    'GetProvisionedProductsProvisionedProductParameterResult',
]

@pulumi.output_type
class ProvisionedProductOutput(dict):
    @staticmethod
    def __key_warning(key: str):
        suggest = None
        if key == "outputKey":
            suggest = "output_key"
        elif key == "outputValue":
            suggest = "output_value"

        if suggest:
            pulumi.log.warn(f"Key '{key}' not found in ProvisionedProductOutput. Access the value via the '{suggest}' property getter instead.")

    def __getitem__(self, key: str) -> Any:
        ProvisionedProductOutput.__key_warning(key)
        return super().__getitem__(key)

    def get(self, key: str, default = None) -> Any:
        ProvisionedProductOutput.__key_warning(key)
        return super().get(key, default)

    def __init__(__self__, *,
                 description: Optional[str] = None,
                 output_key: Optional[str] = None,
                 output_value: Optional[str] = None):
        """
        :param str description: Description of the output value defined in the template.
        :param str output_key: The name of the output value defined in the template.
        :param str output_value: The content of the output value defined in the template.
        """
        if description is not None:
            pulumi.set(__self__, "description", description)
        if output_key is not None:
            pulumi.set(__self__, "output_key", output_key)
        if output_value is not None:
            pulumi.set(__self__, "output_value", output_value)

    @property
    @pulumi.getter
    def description(self) -> Optional[str]:
        """
        Description of the output value defined in the template.
        """
        return pulumi.get(self, "description")

    @property
    @pulumi.getter(name="outputKey")
    def output_key(self) -> Optional[str]:
        """
        The name of the output value defined in the template.
        """
        return pulumi.get(self, "output_key")

    @property
    @pulumi.getter(name="outputValue")
    def output_value(self) -> Optional[str]:
        """
        The content of the output value defined in the template.
        """
        return pulumi.get(self, "output_value")


@pulumi.output_type
class ProvisionedProductParameter(dict):
    @staticmethod
    def __key_warning(key: str):
        suggest = None
        if key == "parameterKey":
            suggest = "parameter_key"
        elif key == "parameterValue":
            suggest = "parameter_value"

        if suggest:
            pulumi.log.warn(f"Key '{key}' not found in ProvisionedProductParameter. Access the value via the '{suggest}' property getter instead.")

    def __getitem__(self, key: str) -> Any:
        ProvisionedProductParameter.__key_warning(key)
        return super().__getitem__(key)

    def get(self, key: str, default = None) -> Any:
        ProvisionedProductParameter.__key_warning(key)
        return super().get(key, default)

    def __init__(__self__, *,
                 parameter_key: Optional[str] = None,
                 parameter_value: Optional[str] = None):
        """
        :param str parameter_key: The name of the parameter defined in the template.
        :param str parameter_value: The Template parameter value entered by the user.
        """
        if parameter_key is not None:
            pulumi.set(__self__, "parameter_key", parameter_key)
        if parameter_value is not None:
            pulumi.set(__self__, "parameter_value", parameter_value)

    @property
    @pulumi.getter(name="parameterKey")
    def parameter_key(self) -> Optional[str]:
        """
        The name of the parameter defined in the template.
        """
        return pulumi.get(self, "parameter_key")

    @property
    @pulumi.getter(name="parameterValue")
    def parameter_value(self) -> Optional[str]:
        """
        The Template parameter value entered by the user.
        """
        return pulumi.get(self, "parameter_value")


@pulumi.output_type
class GetEndUserProductsEndUserProductResult(dict):
    def __init__(__self__, *,
                 create_time: str,
                 description: str,
                 has_default_launch_option: bool,
                 id: str,
                 product_arn: str,
                 product_id: str,
                 product_name: str,
                 product_type: str,
                 provider_name: str):
        """
        :param str create_time: Product creation time.According to ISO8601 standard, UTC time is used in the format: YYYY-MM-DDThh:mm:ssZ.
        :param str description: Product description.
        :param bool has_default_launch_option: Whether there is a default Startup option. Value:-true: There is a default Startup option, and there is no need to fill in the portfolio when starting the product or updating the instance.-false: there is no default Startup option. You must fill in the portfolio when starting the product or updating the instance. For more information about how to obtain the portfolio, see ListLaunchOptions.> If the product is added to only one product portfolio, there will be a default Startup option. If the product is added to multiple product combinations, there will be multiple startup options at the same time, but there is no default Startup option at this time.
        :param str id: ID of product, Its value is the same as `product_id`.
        :param str product_arn: Product ARN.
        :param str product_id: Product ID.
        :param str product_name: Product name.
        :param str product_type: Type of product.The value is Ros, which indicates the resource orchestration service (ROS).
        :param str provider_name: Product provider.
        """
        pulumi.set(__self__, "create_time", create_time)
        pulumi.set(__self__, "description", description)
        pulumi.set(__self__, "has_default_launch_option", has_default_launch_option)
        pulumi.set(__self__, "id", id)
        pulumi.set(__self__, "product_arn", product_arn)
        pulumi.set(__self__, "product_id", product_id)
        pulumi.set(__self__, "product_name", product_name)
        pulumi.set(__self__, "product_type", product_type)
        pulumi.set(__self__, "provider_name", provider_name)

    @property
    @pulumi.getter(name="createTime")
    def create_time(self) -> str:
        """
        Product creation time.According to ISO8601 standard, UTC time is used in the format: YYYY-MM-DDThh:mm:ssZ.
        """
        return pulumi.get(self, "create_time")

    @property
    @pulumi.getter
    def description(self) -> str:
        """
        Product description.
        """
        return pulumi.get(self, "description")

    @property
    @pulumi.getter(name="hasDefaultLaunchOption")
    def has_default_launch_option(self) -> bool:
        """
        Whether there is a default Startup option. Value:-true: There is a default Startup option, and there is no need to fill in the portfolio when starting the product or updating the instance.-false: there is no default Startup option. You must fill in the portfolio when starting the product or updating the instance. For more information about how to obtain the portfolio, see ListLaunchOptions.> If the product is added to only one product portfolio, there will be a default Startup option. If the product is added to multiple product combinations, there will be multiple startup options at the same time, but there is no default Startup option at this time.
        """
        return pulumi.get(self, "has_default_launch_option")

    @property
    @pulumi.getter
    def id(self) -> str:
        """
        ID of product, Its value is the same as `product_id`.
        """
        return pulumi.get(self, "id")

    @property
    @pulumi.getter(name="productArn")
    def product_arn(self) -> str:
        """
        Product ARN.
        """
        return pulumi.get(self, "product_arn")

    @property
    @pulumi.getter(name="productId")
    def product_id(self) -> str:
        """
        Product ID.
        """
        return pulumi.get(self, "product_id")

    @property
    @pulumi.getter(name="productName")
    def product_name(self) -> str:
        """
        Product name.
        """
        return pulumi.get(self, "product_name")

    @property
    @pulumi.getter(name="productType")
    def product_type(self) -> str:
        """
        Type of product.The value is Ros, which indicates the resource orchestration service (ROS).
        """
        return pulumi.get(self, "product_type")

    @property
    @pulumi.getter(name="providerName")
    def provider_name(self) -> str:
        """
        Product provider.
        """
        return pulumi.get(self, "provider_name")


@pulumi.output_type
class GetLaunchOptionsLaunchOptionResult(dict):
    def __init__(__self__, *,
                 constraint_summaries: Sequence['outputs.GetLaunchOptionsLaunchOptionConstraintSummaryResult'],
                 id: str,
                 portfolio_id: str,
                 portfolio_name: str):
        """
        :param Sequence['GetLaunchOptionsLaunchOptionConstraintSummaryArgs'] constraint_summaries: List of constraints.
        :param str id: ID of Service Catalog Launch Option.
        :param str portfolio_id: Product mix ID.
        :param str portfolio_name: Product portfolio name.
        """
        pulumi.set(__self__, "constraint_summaries", constraint_summaries)
        pulumi.set(__self__, "id", id)
        pulumi.set(__self__, "portfolio_id", portfolio_id)
        pulumi.set(__self__, "portfolio_name", portfolio_name)

    @property
    @pulumi.getter(name="constraintSummaries")
    def constraint_summaries(self) -> Sequence['outputs.GetLaunchOptionsLaunchOptionConstraintSummaryResult']:
        """
        List of constraints.
        """
        return pulumi.get(self, "constraint_summaries")

    @property
    @pulumi.getter
    def id(self) -> str:
        """
        ID of Service Catalog Launch Option.
        """
        return pulumi.get(self, "id")

    @property
    @pulumi.getter(name="portfolioId")
    def portfolio_id(self) -> str:
        """
        Product mix ID.
        """
        return pulumi.get(self, "portfolio_id")

    @property
    @pulumi.getter(name="portfolioName")
    def portfolio_name(self) -> str:
        """
        Product portfolio name.
        """
        return pulumi.get(self, "portfolio_name")


@pulumi.output_type
class GetLaunchOptionsLaunchOptionConstraintSummaryResult(dict):
    def __init__(__self__, *,
                 constraint_type: str,
                 description: str):
        """
        :param str constraint_type: Constraint type.The value is Launch, which indicates that the constraint is started.
        :param str description: Constraint description.
        """
        pulumi.set(__self__, "constraint_type", constraint_type)
        pulumi.set(__self__, "description", description)

    @property
    @pulumi.getter(name="constraintType")
    def constraint_type(self) -> str:
        """
        Constraint type.The value is Launch, which indicates that the constraint is started.
        """
        return pulumi.get(self, "constraint_type")

    @property
    @pulumi.getter
    def description(self) -> str:
        """
        Constraint description.
        """
        return pulumi.get(self, "description")


@pulumi.output_type
class GetLaunchOptionsOptionResult(dict):
    def __init__(__self__, *,
                 constraint_summaries: Sequence['outputs.GetLaunchOptionsOptionConstraintSummaryResult'],
                 id: str,
                 portfolio_id: str,
                 portfolio_name: str):
        """
        :param Sequence['GetLaunchOptionsOptionConstraintSummaryArgs'] constraint_summaries: List of constraints.
        :param str id: ID of Service Catalog Launch Option.
        :param str portfolio_id: Product mix ID.
        :param str portfolio_name: Product portfolio name.
        """
        pulumi.set(__self__, "constraint_summaries", constraint_summaries)
        pulumi.set(__self__, "id", id)
        pulumi.set(__self__, "portfolio_id", portfolio_id)
        pulumi.set(__self__, "portfolio_name", portfolio_name)

    @property
    @pulumi.getter(name="constraintSummaries")
    def constraint_summaries(self) -> Sequence['outputs.GetLaunchOptionsOptionConstraintSummaryResult']:
        """
        List of constraints.
        """
        return pulumi.get(self, "constraint_summaries")

    @property
    @pulumi.getter
    def id(self) -> str:
        """
        ID of Service Catalog Launch Option.
        """
        return pulumi.get(self, "id")

    @property
    @pulumi.getter(name="portfolioId")
    def portfolio_id(self) -> str:
        """
        Product mix ID.
        """
        return pulumi.get(self, "portfolio_id")

    @property
    @pulumi.getter(name="portfolioName")
    def portfolio_name(self) -> str:
        """
        Product portfolio name.
        """
        return pulumi.get(self, "portfolio_name")


@pulumi.output_type
class GetLaunchOptionsOptionConstraintSummaryResult(dict):
    def __init__(__self__, *,
                 constraint_type: str,
                 description: str):
        """
        :param str constraint_type: Constraint type.The value is Launch, which indicates that the constraint is started.
        :param str description: Constraint description.
        """
        pulumi.set(__self__, "constraint_type", constraint_type)
        pulumi.set(__self__, "description", description)

    @property
    @pulumi.getter(name="constraintType")
    def constraint_type(self) -> str:
        """
        Constraint type.The value is Launch, which indicates that the constraint is started.
        """
        return pulumi.get(self, "constraint_type")

    @property
    @pulumi.getter
    def description(self) -> str:
        """
        Constraint description.
        """
        return pulumi.get(self, "description")


@pulumi.output_type
class GetPortfoliosPortfolioResult(dict):
    def __init__(__self__, *,
                 create_time: str,
                 description: str,
                 id: str,
                 portfolio_arn: str,
                 portfolio_id: str,
                 portfolio_name: str,
                 provider_name: str):
        """
        :param str create_time: The creation time of the portfolio
        :param str description: The description of the portfolio
        :param str id: The ID of the portfolio
        :param str portfolio_arn: The ARN of the portfolio
        :param str portfolio_id: The ID of the portfolio
        :param str portfolio_name: The name of the portfolio
        :param str provider_name: The provider name of the portfolio
        """
        pulumi.set(__self__, "create_time", create_time)
        pulumi.set(__self__, "description", description)
        pulumi.set(__self__, "id", id)
        pulumi.set(__self__, "portfolio_arn", portfolio_arn)
        pulumi.set(__self__, "portfolio_id", portfolio_id)
        pulumi.set(__self__, "portfolio_name", portfolio_name)
        pulumi.set(__self__, "provider_name", provider_name)

    @property
    @pulumi.getter(name="createTime")
    def create_time(self) -> str:
        """
        The creation time of the portfolio
        """
        return pulumi.get(self, "create_time")

    @property
    @pulumi.getter
    def description(self) -> str:
        """
        The description of the portfolio
        """
        return pulumi.get(self, "description")

    @property
    @pulumi.getter
    def id(self) -> str:
        """
        The ID of the portfolio
        """
        return pulumi.get(self, "id")

    @property
    @pulumi.getter(name="portfolioArn")
    def portfolio_arn(self) -> str:
        """
        The ARN of the portfolio
        """
        return pulumi.get(self, "portfolio_arn")

    @property
    @pulumi.getter(name="portfolioId")
    def portfolio_id(self) -> str:
        """
        The ID of the portfolio
        """
        return pulumi.get(self, "portfolio_id")

    @property
    @pulumi.getter(name="portfolioName")
    def portfolio_name(self) -> str:
        """
        The name of the portfolio
        """
        return pulumi.get(self, "portfolio_name")

    @property
    @pulumi.getter(name="providerName")
    def provider_name(self) -> str:
        """
        The provider name of the portfolio
        """
        return pulumi.get(self, "provider_name")


@pulumi.output_type
class GetProductAsEndUsersUserResult(dict):
    def __init__(__self__, *,
                 create_time: str,
                 description: str,
                 has_default_launch_option: bool,
                 id: str,
                 product_arn: str,
                 product_id: str,
                 product_name: str,
                 product_type: str,
                 provider_name: str):
        """
        :param str create_time: Product creation time.According to ISO8601 standard, UTC time is used in the format: YYYY-MM-DDThh:mm:ssZ.
        :param str description: Product description.
        :param bool has_default_launch_option: Whether there is a default Startup option. Value:-true: There is a default Startup option, and there is no need to fill in the portfolio when starting the product or updating the instance.-false: there is no default Startup option. You must fill in the portfolio when starting the product or updating the instance. > If the product is added to only one product portfolio, there will be a default Startup option. If the product is added to multiple product combinations, there will be multiple startup options at the same time, but there is no default Startup option at this time.
        :param str id: ID of product, Its value is the same as `product_id`.
        :param str product_arn: Product ARN.
        :param str product_id: Product ID.
        :param str product_name: Product name.
        :param str product_type: Type of product.The value is Ros, which indicates the resource orchestration service (ROS).
        :param str provider_name: Product provider.
        """
        pulumi.set(__self__, "create_time", create_time)
        pulumi.set(__self__, "description", description)
        pulumi.set(__self__, "has_default_launch_option", has_default_launch_option)
        pulumi.set(__self__, "id", id)
        pulumi.set(__self__, "product_arn", product_arn)
        pulumi.set(__self__, "product_id", product_id)
        pulumi.set(__self__, "product_name", product_name)
        pulumi.set(__self__, "product_type", product_type)
        pulumi.set(__self__, "provider_name", provider_name)

    @property
    @pulumi.getter(name="createTime")
    def create_time(self) -> str:
        """
        Product creation time.According to ISO8601 standard, UTC time is used in the format: YYYY-MM-DDThh:mm:ssZ.
        """
        return pulumi.get(self, "create_time")

    @property
    @pulumi.getter
    def description(self) -> str:
        """
        Product description.
        """
        return pulumi.get(self, "description")

    @property
    @pulumi.getter(name="hasDefaultLaunchOption")
    def has_default_launch_option(self) -> bool:
        """
        Whether there is a default Startup option. Value:-true: There is a default Startup option, and there is no need to fill in the portfolio when starting the product or updating the instance.-false: there is no default Startup option. You must fill in the portfolio when starting the product or updating the instance. > If the product is added to only one product portfolio, there will be a default Startup option. If the product is added to multiple product combinations, there will be multiple startup options at the same time, but there is no default Startup option at this time.
        """
        return pulumi.get(self, "has_default_launch_option")

    @property
    @pulumi.getter
    def id(self) -> str:
        """
        ID of product, Its value is the same as `product_id`.
        """
        return pulumi.get(self, "id")

    @property
    @pulumi.getter(name="productArn")
    def product_arn(self) -> str:
        """
        Product ARN.
        """
        return pulumi.get(self, "product_arn")

    @property
    @pulumi.getter(name="productId")
    def product_id(self) -> str:
        """
        Product ID.
        """
        return pulumi.get(self, "product_id")

    @property
    @pulumi.getter(name="productName")
    def product_name(self) -> str:
        """
        Product name.
        """
        return pulumi.get(self, "product_name")

    @property
    @pulumi.getter(name="productType")
    def product_type(self) -> str:
        """
        Type of product.The value is Ros, which indicates the resource orchestration service (ROS).
        """
        return pulumi.get(self, "product_type")

    @property
    @pulumi.getter(name="providerName")
    def provider_name(self) -> str:
        """
        Product provider.
        """
        return pulumi.get(self, "provider_name")


@pulumi.output_type
class GetProductVersionsProductVersionResult(dict):
    def __init__(__self__, *,
                 active: bool,
                 create_time: str,
                 description: str,
                 guidance: str,
                 id: str,
                 product_id: str,
                 product_version_id: str,
                 product_version_name: str,
                 template_type: str,
                 template_url: str):
        """
        :param bool active: Whether the version is activated
        :param str create_time: The creation time of the resource
        :param str description: Version description
        :param str guidance: Administrator guidance
        :param str id: ID of product version.
        :param str product_id: Product ID
        :param str product_version_id: The first ID of the resource
        :param str product_version_name: The name of the resource
        :param str template_type: Template Type
        :param str template_url: Template URL
        """
        pulumi.set(__self__, "active", active)
        pulumi.set(__self__, "create_time", create_time)
        pulumi.set(__self__, "description", description)
        pulumi.set(__self__, "guidance", guidance)
        pulumi.set(__self__, "id", id)
        pulumi.set(__self__, "product_id", product_id)
        pulumi.set(__self__, "product_version_id", product_version_id)
        pulumi.set(__self__, "product_version_name", product_version_name)
        pulumi.set(__self__, "template_type", template_type)
        pulumi.set(__self__, "template_url", template_url)

    @property
    @pulumi.getter
    def active(self) -> bool:
        """
        Whether the version is activated
        """
        return pulumi.get(self, "active")

    @property
    @pulumi.getter(name="createTime")
    def create_time(self) -> str:
        """
        The creation time of the resource
        """
        return pulumi.get(self, "create_time")

    @property
    @pulumi.getter
    def description(self) -> str:
        """
        Version description
        """
        return pulumi.get(self, "description")

    @property
    @pulumi.getter
    def guidance(self) -> str:
        """
        Administrator guidance
        """
        return pulumi.get(self, "guidance")

    @property
    @pulumi.getter
    def id(self) -> str:
        """
        ID of product version.
        """
        return pulumi.get(self, "id")

    @property
    @pulumi.getter(name="productId")
    def product_id(self) -> str:
        """
        Product ID
        """
        return pulumi.get(self, "product_id")

    @property
    @pulumi.getter(name="productVersionId")
    def product_version_id(self) -> str:
        """
        The first ID of the resource
        """
        return pulumi.get(self, "product_version_id")

    @property
    @pulumi.getter(name="productVersionName")
    def product_version_name(self) -> str:
        """
        The name of the resource
        """
        return pulumi.get(self, "product_version_name")

    @property
    @pulumi.getter(name="templateType")
    def template_type(self) -> str:
        """
        Template Type
        """
        return pulumi.get(self, "template_type")

    @property
    @pulumi.getter(name="templateUrl")
    def template_url(self) -> str:
        """
        Template URL
        """
        return pulumi.get(self, "template_url")


@pulumi.output_type
class GetProductVersionsVersionResult(dict):
    def __init__(__self__, *,
                 active: bool,
                 create_time: str,
                 description: str,
                 guidance: str,
                 id: str,
                 product_id: str,
                 product_version_id: str,
                 product_version_name: str,
                 template_type: str,
                 template_url: str):
        """
        :param bool active: Whether the version is activated
        :param str create_time: The creation time of the resource
        :param str description: Version description
        :param str guidance: Administrator guidance
        :param str id: ID of product version.
        :param str product_id: Product ID
        :param str product_version_id: The first ID of the resource
        :param str product_version_name: The name of the resource
        :param str template_type: Template Type
        :param str template_url: Template URL
        """
        pulumi.set(__self__, "active", active)
        pulumi.set(__self__, "create_time", create_time)
        pulumi.set(__self__, "description", description)
        pulumi.set(__self__, "guidance", guidance)
        pulumi.set(__self__, "id", id)
        pulumi.set(__self__, "product_id", product_id)
        pulumi.set(__self__, "product_version_id", product_version_id)
        pulumi.set(__self__, "product_version_name", product_version_name)
        pulumi.set(__self__, "template_type", template_type)
        pulumi.set(__self__, "template_url", template_url)

    @property
    @pulumi.getter
    def active(self) -> bool:
        """
        Whether the version is activated
        """
        return pulumi.get(self, "active")

    @property
    @pulumi.getter(name="createTime")
    def create_time(self) -> str:
        """
        The creation time of the resource
        """
        return pulumi.get(self, "create_time")

    @property
    @pulumi.getter
    def description(self) -> str:
        """
        Version description
        """
        return pulumi.get(self, "description")

    @property
    @pulumi.getter
    def guidance(self) -> str:
        """
        Administrator guidance
        """
        return pulumi.get(self, "guidance")

    @property
    @pulumi.getter
    def id(self) -> str:
        """
        ID of product version.
        """
        return pulumi.get(self, "id")

    @property
    @pulumi.getter(name="productId")
    def product_id(self) -> str:
        """
        Product ID
        """
        return pulumi.get(self, "product_id")

    @property
    @pulumi.getter(name="productVersionId")
    def product_version_id(self) -> str:
        """
        The first ID of the resource
        """
        return pulumi.get(self, "product_version_id")

    @property
    @pulumi.getter(name="productVersionName")
    def product_version_name(self) -> str:
        """
        The name of the resource
        """
        return pulumi.get(self, "product_version_name")

    @property
    @pulumi.getter(name="templateType")
    def template_type(self) -> str:
        """
        Template Type
        """
        return pulumi.get(self, "template_type")

    @property
    @pulumi.getter(name="templateUrl")
    def template_url(self) -> str:
        """
        Template URL
        """
        return pulumi.get(self, "template_url")


@pulumi.output_type
class GetProvisionedProductsProductResult(dict):
    def __init__(__self__, *,
                 create_time: str,
                 id: str,
                 last_provisioning_task_id: str,
                 last_successful_provisioning_task_id: str,
                 last_task_id: str,
                 outputs: Sequence['outputs.GetProvisionedProductsProductOutputResult'],
                 owner_principal_id: str,
                 owner_principal_type: str,
                 parameters: Sequence['outputs.GetProvisionedProductsProductParameterResult'],
                 portfolio_id: str,
                 product_id: str,
                 product_name: str,
                 product_version_id: str,
                 product_version_name: str,
                 provisioned_product_arn: str,
                 provisioned_product_id: str,
                 provisioned_product_name: str,
                 provisioned_product_type: str,
                 stack_id: str,
                 stack_region_id: str,
                 status: str,
                 status_message: str,
                 tags: Optional[Mapping[str, Any]] = None):
        """
        :param str create_time: The creation time of the product instance
        :param str last_provisioning_task_id: The ID of the last instance operation task
        :param str last_successful_provisioning_task_id: The ID of the last successful instance operation task
        :param str last_task_id: The ID of the last task
        :param str owner_principal_id: The RAM entity ID of the owner
        :param str owner_principal_type: The RAM entity type of the owner
        :param str portfolio_id: Product mix ID.> When there is a default Startup option, there is no need to fill in the portfolio. When there is no default Startup option, you must fill in the portfolio.
        :param str product_id: Product ID.
        :param str product_name: The name of the product
        :param str product_version_id: Product version ID.
        :param str product_version_name: The name of the product version
        :param str provisioned_product_arn: The ARN of the product instance
        :param str provisioned_product_id: The ID of the instance.
        :param str provisioned_product_name: The name of the instance.The length is 1~128 characters.
        :param str provisioned_product_type: Instance type.The value is RosStack, which indicates the stack of Alibaba Cloud resource orchestration service (ROS).
        :param str stack_id: The ID of the ROS stack
        :param str stack_region_id: The ID of the region to which the resource stack of the Alibaba Cloud resource orchestration service (ROS) belongs.
        :param str status: Instance status
        :param str status_message: The status message of the product instance
        """
        pulumi.set(__self__, "create_time", create_time)
        pulumi.set(__self__, "id", id)
        pulumi.set(__self__, "last_provisioning_task_id", last_provisioning_task_id)
        pulumi.set(__self__, "last_successful_provisioning_task_id", last_successful_provisioning_task_id)
        pulumi.set(__self__, "last_task_id", last_task_id)
        pulumi.set(__self__, "outputs", outputs)
        pulumi.set(__self__, "owner_principal_id", owner_principal_id)
        pulumi.set(__self__, "owner_principal_type", owner_principal_type)
        pulumi.set(__self__, "parameters", parameters)
        pulumi.set(__self__, "portfolio_id", portfolio_id)
        pulumi.set(__self__, "product_id", product_id)
        pulumi.set(__self__, "product_name", product_name)
        pulumi.set(__self__, "product_version_id", product_version_id)
        pulumi.set(__self__, "product_version_name", product_version_name)
        pulumi.set(__self__, "provisioned_product_arn", provisioned_product_arn)
        pulumi.set(__self__, "provisioned_product_id", provisioned_product_id)
        pulumi.set(__self__, "provisioned_product_name", provisioned_product_name)
        pulumi.set(__self__, "provisioned_product_type", provisioned_product_type)
        pulumi.set(__self__, "stack_id", stack_id)
        pulumi.set(__self__, "stack_region_id", stack_region_id)
        pulumi.set(__self__, "status", status)
        pulumi.set(__self__, "status_message", status_message)
        if tags is not None:
            pulumi.set(__self__, "tags", tags)

    @property
    @pulumi.getter(name="createTime")
    def create_time(self) -> str:
        """
        The creation time of the product instance
        """
        return pulumi.get(self, "create_time")

    @property
    @pulumi.getter
    def id(self) -> str:
        return pulumi.get(self, "id")

    @property
    @pulumi.getter(name="lastProvisioningTaskId")
    def last_provisioning_task_id(self) -> str:
        """
        The ID of the last instance operation task
        """
        return pulumi.get(self, "last_provisioning_task_id")

    @property
    @pulumi.getter(name="lastSuccessfulProvisioningTaskId")
    def last_successful_provisioning_task_id(self) -> str:
        """
        The ID of the last successful instance operation task
        """
        return pulumi.get(self, "last_successful_provisioning_task_id")

    @property
    @pulumi.getter(name="lastTaskId")
    def last_task_id(self) -> str:
        """
        The ID of the last task
        """
        return pulumi.get(self, "last_task_id")

    @property
    @pulumi.getter
    def outputs(self) -> Sequence['outputs.GetProvisionedProductsProductOutputResult']:
        return pulumi.get(self, "outputs")

    @property
    @pulumi.getter(name="ownerPrincipalId")
    def owner_principal_id(self) -> str:
        """
        The RAM entity ID of the owner
        """
        return pulumi.get(self, "owner_principal_id")

    @property
    @pulumi.getter(name="ownerPrincipalType")
    def owner_principal_type(self) -> str:
        """
        The RAM entity type of the owner
        """
        return pulumi.get(self, "owner_principal_type")

    @property
    @pulumi.getter
    def parameters(self) -> Sequence['outputs.GetProvisionedProductsProductParameterResult']:
        return pulumi.get(self, "parameters")

    @property
    @pulumi.getter(name="portfolioId")
    def portfolio_id(self) -> str:
        """
        Product mix ID.> When there is a default Startup option, there is no need to fill in the portfolio. When there is no default Startup option, you must fill in the portfolio.
        """
        return pulumi.get(self, "portfolio_id")

    @property
    @pulumi.getter(name="productId")
    def product_id(self) -> str:
        """
        Product ID.
        """
        return pulumi.get(self, "product_id")

    @property
    @pulumi.getter(name="productName")
    def product_name(self) -> str:
        """
        The name of the product
        """
        return pulumi.get(self, "product_name")

    @property
    @pulumi.getter(name="productVersionId")
    def product_version_id(self) -> str:
        """
        Product version ID.
        """
        return pulumi.get(self, "product_version_id")

    @property
    @pulumi.getter(name="productVersionName")
    def product_version_name(self) -> str:
        """
        The name of the product version
        """
        return pulumi.get(self, "product_version_name")

    @property
    @pulumi.getter(name="provisionedProductArn")
    def provisioned_product_arn(self) -> str:
        """
        The ARN of the product instance
        """
        return pulumi.get(self, "provisioned_product_arn")

    @property
    @pulumi.getter(name="provisionedProductId")
    def provisioned_product_id(self) -> str:
        """
        The ID of the instance.
        """
        return pulumi.get(self, "provisioned_product_id")

    @property
    @pulumi.getter(name="provisionedProductName")
    def provisioned_product_name(self) -> str:
        """
        The name of the instance.The length is 1~128 characters.
        """
        return pulumi.get(self, "provisioned_product_name")

    @property
    @pulumi.getter(name="provisionedProductType")
    def provisioned_product_type(self) -> str:
        """
        Instance type.The value is RosStack, which indicates the stack of Alibaba Cloud resource orchestration service (ROS).
        """
        return pulumi.get(self, "provisioned_product_type")

    @property
    @pulumi.getter(name="stackId")
    def stack_id(self) -> str:
        """
        The ID of the ROS stack
        """
        return pulumi.get(self, "stack_id")

    @property
    @pulumi.getter(name="stackRegionId")
    def stack_region_id(self) -> str:
        """
        The ID of the region to which the resource stack of the Alibaba Cloud resource orchestration service (ROS) belongs.
        """
        return pulumi.get(self, "stack_region_id")

    @property
    @pulumi.getter
    def status(self) -> str:
        """
        Instance status
        """
        return pulumi.get(self, "status")

    @property
    @pulumi.getter(name="statusMessage")
    def status_message(self) -> str:
        """
        The status message of the product instance
        """
        return pulumi.get(self, "status_message")

    @property
    @pulumi.getter
    def tags(self) -> Optional[Mapping[str, Any]]:
        return pulumi.get(self, "tags")


@pulumi.output_type
class GetProvisionedProductsProductOutputResult(dict):
    def __init__(__self__, *,
                 description: str,
                 output_key: str,
                 output_value: str):
        pulumi.set(__self__, "description", description)
        pulumi.set(__self__, "output_key", output_key)
        pulumi.set(__self__, "output_value", output_value)

    @property
    @pulumi.getter
    def description(self) -> str:
        return pulumi.get(self, "description")

    @property
    @pulumi.getter(name="outputKey")
    def output_key(self) -> str:
        return pulumi.get(self, "output_key")

    @property
    @pulumi.getter(name="outputValue")
    def output_value(self) -> str:
        return pulumi.get(self, "output_value")


@pulumi.output_type
class GetProvisionedProductsProductParameterResult(dict):
    def __init__(__self__, *,
                 parameter_key: str,
                 parameter_value: str):
        pulumi.set(__self__, "parameter_key", parameter_key)
        pulumi.set(__self__, "parameter_value", parameter_value)

    @property
    @pulumi.getter(name="parameterKey")
    def parameter_key(self) -> str:
        return pulumi.get(self, "parameter_key")

    @property
    @pulumi.getter(name="parameterValue")
    def parameter_value(self) -> str:
        return pulumi.get(self, "parameter_value")


@pulumi.output_type
class GetProvisionedProductsProvisionedProductResult(dict):
    def __init__(__self__, *,
                 create_time: str,
                 id: str,
                 last_provisioning_task_id: str,
                 last_successful_provisioning_task_id: str,
                 last_task_id: str,
                 outputs: Sequence['outputs.GetProvisionedProductsProvisionedProductOutputResult'],
                 owner_principal_id: str,
                 owner_principal_type: str,
                 parameters: Sequence['outputs.GetProvisionedProductsProvisionedProductParameterResult'],
                 portfolio_id: str,
                 product_id: str,
                 product_name: str,
                 product_version_id: str,
                 product_version_name: str,
                 provisioned_product_arn: str,
                 provisioned_product_id: str,
                 provisioned_product_name: str,
                 provisioned_product_type: str,
                 stack_id: str,
                 stack_region_id: str,
                 status: str,
                 status_message: str,
                 tags: Optional[Mapping[str, Any]] = None):
        """
        :param str create_time: The creation time of the product instance
        :param str last_provisioning_task_id: The ID of the last instance operation task
        :param str last_successful_provisioning_task_id: The ID of the last successful instance operation task
        :param str last_task_id: The ID of the last task
        :param str owner_principal_id: The RAM entity ID of the owner
        :param str owner_principal_type: The RAM entity type of the owner
        :param str portfolio_id: Product mix ID.> When there is a default Startup option, there is no need to fill in the portfolio. When there is no default Startup option, you must fill in the portfolio.
        :param str product_id: Product ID.
        :param str product_name: The name of the product
        :param str product_version_id: Product version ID.
        :param str product_version_name: The name of the product version
        :param str provisioned_product_arn: The ARN of the product instance
        :param str provisioned_product_id: The ID of the instance.
        :param str provisioned_product_name: The name of the instance.The length is 1~128 characters.
        :param str provisioned_product_type: Instance type.The value is RosStack, which indicates the stack of Alibaba Cloud resource orchestration service (ROS).
        :param str stack_id: The ID of the ROS stack
        :param str stack_region_id: The ID of the region to which the resource stack of the Alibaba Cloud resource orchestration service (ROS) belongs.
        :param str status: Instance status
        :param str status_message: The status message of the product instance
        """
        pulumi.set(__self__, "create_time", create_time)
        pulumi.set(__self__, "id", id)
        pulumi.set(__self__, "last_provisioning_task_id", last_provisioning_task_id)
        pulumi.set(__self__, "last_successful_provisioning_task_id", last_successful_provisioning_task_id)
        pulumi.set(__self__, "last_task_id", last_task_id)
        pulumi.set(__self__, "outputs", outputs)
        pulumi.set(__self__, "owner_principal_id", owner_principal_id)
        pulumi.set(__self__, "owner_principal_type", owner_principal_type)
        pulumi.set(__self__, "parameters", parameters)
        pulumi.set(__self__, "portfolio_id", portfolio_id)
        pulumi.set(__self__, "product_id", product_id)
        pulumi.set(__self__, "product_name", product_name)
        pulumi.set(__self__, "product_version_id", product_version_id)
        pulumi.set(__self__, "product_version_name", product_version_name)
        pulumi.set(__self__, "provisioned_product_arn", provisioned_product_arn)
        pulumi.set(__self__, "provisioned_product_id", provisioned_product_id)
        pulumi.set(__self__, "provisioned_product_name", provisioned_product_name)
        pulumi.set(__self__, "provisioned_product_type", provisioned_product_type)
        pulumi.set(__self__, "stack_id", stack_id)
        pulumi.set(__self__, "stack_region_id", stack_region_id)
        pulumi.set(__self__, "status", status)
        pulumi.set(__self__, "status_message", status_message)
        if tags is not None:
            pulumi.set(__self__, "tags", tags)

    @property
    @pulumi.getter(name="createTime")
    def create_time(self) -> str:
        """
        The creation time of the product instance
        """
        return pulumi.get(self, "create_time")

    @property
    @pulumi.getter
    def id(self) -> str:
        return pulumi.get(self, "id")

    @property
    @pulumi.getter(name="lastProvisioningTaskId")
    def last_provisioning_task_id(self) -> str:
        """
        The ID of the last instance operation task
        """
        return pulumi.get(self, "last_provisioning_task_id")

    @property
    @pulumi.getter(name="lastSuccessfulProvisioningTaskId")
    def last_successful_provisioning_task_id(self) -> str:
        """
        The ID of the last successful instance operation task
        """
        return pulumi.get(self, "last_successful_provisioning_task_id")

    @property
    @pulumi.getter(name="lastTaskId")
    def last_task_id(self) -> str:
        """
        The ID of the last task
        """
        return pulumi.get(self, "last_task_id")

    @property
    @pulumi.getter
    def outputs(self) -> Sequence['outputs.GetProvisionedProductsProvisionedProductOutputResult']:
        return pulumi.get(self, "outputs")

    @property
    @pulumi.getter(name="ownerPrincipalId")
    def owner_principal_id(self) -> str:
        """
        The RAM entity ID of the owner
        """
        return pulumi.get(self, "owner_principal_id")

    @property
    @pulumi.getter(name="ownerPrincipalType")
    def owner_principal_type(self) -> str:
        """
        The RAM entity type of the owner
        """
        return pulumi.get(self, "owner_principal_type")

    @property
    @pulumi.getter
    def parameters(self) -> Sequence['outputs.GetProvisionedProductsProvisionedProductParameterResult']:
        return pulumi.get(self, "parameters")

    @property
    @pulumi.getter(name="portfolioId")
    def portfolio_id(self) -> str:
        """
        Product mix ID.> When there is a default Startup option, there is no need to fill in the portfolio. When there is no default Startup option, you must fill in the portfolio.
        """
        return pulumi.get(self, "portfolio_id")

    @property
    @pulumi.getter(name="productId")
    def product_id(self) -> str:
        """
        Product ID.
        """
        return pulumi.get(self, "product_id")

    @property
    @pulumi.getter(name="productName")
    def product_name(self) -> str:
        """
        The name of the product
        """
        return pulumi.get(self, "product_name")

    @property
    @pulumi.getter(name="productVersionId")
    def product_version_id(self) -> str:
        """
        Product version ID.
        """
        return pulumi.get(self, "product_version_id")

    @property
    @pulumi.getter(name="productVersionName")
    def product_version_name(self) -> str:
        """
        The name of the product version
        """
        return pulumi.get(self, "product_version_name")

    @property
    @pulumi.getter(name="provisionedProductArn")
    def provisioned_product_arn(self) -> str:
        """
        The ARN of the product instance
        """
        return pulumi.get(self, "provisioned_product_arn")

    @property
    @pulumi.getter(name="provisionedProductId")
    def provisioned_product_id(self) -> str:
        """
        The ID of the instance.
        """
        return pulumi.get(self, "provisioned_product_id")

    @property
    @pulumi.getter(name="provisionedProductName")
    def provisioned_product_name(self) -> str:
        """
        The name of the instance.The length is 1~128 characters.
        """
        return pulumi.get(self, "provisioned_product_name")

    @property
    @pulumi.getter(name="provisionedProductType")
    def provisioned_product_type(self) -> str:
        """
        Instance type.The value is RosStack, which indicates the stack of Alibaba Cloud resource orchestration service (ROS).
        """
        return pulumi.get(self, "provisioned_product_type")

    @property
    @pulumi.getter(name="stackId")
    def stack_id(self) -> str:
        """
        The ID of the ROS stack
        """
        return pulumi.get(self, "stack_id")

    @property
    @pulumi.getter(name="stackRegionId")
    def stack_region_id(self) -> str:
        """
        The ID of the region to which the resource stack of the Alibaba Cloud resource orchestration service (ROS) belongs.
        """
        return pulumi.get(self, "stack_region_id")

    @property
    @pulumi.getter
    def status(self) -> str:
        """
        Instance status
        """
        return pulumi.get(self, "status")

    @property
    @pulumi.getter(name="statusMessage")
    def status_message(self) -> str:
        """
        The status message of the product instance
        """
        return pulumi.get(self, "status_message")

    @property
    @pulumi.getter
    def tags(self) -> Optional[Mapping[str, Any]]:
        return pulumi.get(self, "tags")


@pulumi.output_type
class GetProvisionedProductsProvisionedProductOutputResult(dict):
    def __init__(__self__, *,
                 description: str,
                 output_key: str,
                 output_value: str):
        pulumi.set(__self__, "description", description)
        pulumi.set(__self__, "output_key", output_key)
        pulumi.set(__self__, "output_value", output_value)

    @property
    @pulumi.getter
    def description(self) -> str:
        return pulumi.get(self, "description")

    @property
    @pulumi.getter(name="outputKey")
    def output_key(self) -> str:
        return pulumi.get(self, "output_key")

    @property
    @pulumi.getter(name="outputValue")
    def output_value(self) -> str:
        return pulumi.get(self, "output_value")


@pulumi.output_type
class GetProvisionedProductsProvisionedProductParameterResult(dict):
    def __init__(__self__, *,
                 parameter_key: str,
                 parameter_value: str):
        pulumi.set(__self__, "parameter_key", parameter_key)
        pulumi.set(__self__, "parameter_value", parameter_value)

    @property
    @pulumi.getter(name="parameterKey")
    def parameter_key(self) -> str:
        return pulumi.get(self, "parameter_key")

    @property
    @pulumi.getter(name="parameterValue")
    def parameter_value(self) -> str:
        return pulumi.get(self, "parameter_value")





# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
from .. import _utilities

__all__ = ['ClusterArgs', 'Cluster']

@pulumi.input_type
class ClusterArgs:
    def __init__(__self__, *,
                 cluster_specification: pulumi.Input[str],
                 cluster_type: pulumi.Input[str],
                 cluster_version: pulumi.Input[str],
                 instance_count: pulumi.Input[int],
                 net_type: pulumi.Input[str],
                 pub_network_flow: pulumi.Input[str],
                 acl_entry_lists: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None,
                 cluster_alias_name: Optional[pulumi.Input[str]] = None,
                 connection_type: Optional[pulumi.Input[str]] = None,
                 disk_type: Optional[pulumi.Input[str]] = None,
                 mse_version: Optional[pulumi.Input[str]] = None,
                 private_slb_specification: Optional[pulumi.Input[str]] = None,
                 pub_slb_specification: Optional[pulumi.Input[str]] = None,
                 request_pars: Optional[pulumi.Input[str]] = None,
                 vpc_id: Optional[pulumi.Input[str]] = None,
                 vswitch_id: Optional[pulumi.Input[str]] = None):
        """
        The set of arguments for constructing a Cluster resource.
        :param pulumi.Input[str] cluster_specification: The engine specification of MSE Cluster. **NOTE:** From version 1.188.0, `cluster_specification` can be modified. Valid values:
        :param pulumi.Input[str] cluster_type: The type of MSE Cluster.
        :param pulumi.Input[str] cluster_version: The version of MSE Cluster. See [details](https://www.alibabacloud.com/help/en/microservices-engine/latest/api-doc-mse-2019-05-31-api-doc-createcluster)
        :param pulumi.Input[int] instance_count: The count of instance. **NOTE:** From version 1.188.0, `instance_count` can be modified.
        :param pulumi.Input[str] net_type: The type of network. Valid values: "privatenet" and "pubnet".
        :param pulumi.Input[str] pub_network_flow: The public network bandwidth. `0` means no access to the public network.
        :param pulumi.Input[Sequence[pulumi.Input[str]]] acl_entry_lists: The whitelist. **NOTE:** This attribute is invalid when the value of `pub_network_flow` is `0` and the value of `net_type` is `privatenet`.
        :param pulumi.Input[str] cluster_alias_name: The alias of MSE Cluster.
        :param pulumi.Input[str] connection_type: The connection type. Valid values: `slb`.
        :param pulumi.Input[str] disk_type: The type of Disk.
        :param pulumi.Input[str] mse_version: The version of MSE. Valid values: `mse_dev` or `mse_pro`.
        :param pulumi.Input[str] private_slb_specification: The specification of private network SLB.
        :param pulumi.Input[str] pub_slb_specification: The specification of public network SLB.
        :param pulumi.Input[str] request_pars: The extended request parameters in the JSON format.
        :param pulumi.Input[str] vpc_id: The id of the VPC.
        :param pulumi.Input[str] vswitch_id: The id of VSwitch.
        """
        pulumi.set(__self__, "cluster_specification", cluster_specification)
        pulumi.set(__self__, "cluster_type", cluster_type)
        pulumi.set(__self__, "cluster_version", cluster_version)
        pulumi.set(__self__, "instance_count", instance_count)
        pulumi.set(__self__, "net_type", net_type)
        pulumi.set(__self__, "pub_network_flow", pub_network_flow)
        if acl_entry_lists is not None:
            pulumi.set(__self__, "acl_entry_lists", acl_entry_lists)
        if cluster_alias_name is not None:
            pulumi.set(__self__, "cluster_alias_name", cluster_alias_name)
        if connection_type is not None:
            pulumi.set(__self__, "connection_type", connection_type)
        if disk_type is not None:
            pulumi.set(__self__, "disk_type", disk_type)
        if mse_version is not None:
            pulumi.set(__self__, "mse_version", mse_version)
        if private_slb_specification is not None:
            pulumi.set(__self__, "private_slb_specification", private_slb_specification)
        if pub_slb_specification is not None:
            pulumi.set(__self__, "pub_slb_specification", pub_slb_specification)
        if request_pars is not None:
            pulumi.set(__self__, "request_pars", request_pars)
        if vpc_id is not None:
            pulumi.set(__self__, "vpc_id", vpc_id)
        if vswitch_id is not None:
            pulumi.set(__self__, "vswitch_id", vswitch_id)

    @property
    @pulumi.getter(name="clusterSpecification")
    def cluster_specification(self) -> pulumi.Input[str]:
        """
        The engine specification of MSE Cluster. **NOTE:** From version 1.188.0, `cluster_specification` can be modified. Valid values:
        """
        return pulumi.get(self, "cluster_specification")

    @cluster_specification.setter
    def cluster_specification(self, value: pulumi.Input[str]):
        pulumi.set(self, "cluster_specification", value)

    @property
    @pulumi.getter(name="clusterType")
    def cluster_type(self) -> pulumi.Input[str]:
        """
        The type of MSE Cluster.
        """
        return pulumi.get(self, "cluster_type")

    @cluster_type.setter
    def cluster_type(self, value: pulumi.Input[str]):
        pulumi.set(self, "cluster_type", value)

    @property
    @pulumi.getter(name="clusterVersion")
    def cluster_version(self) -> pulumi.Input[str]:
        """
        The version of MSE Cluster. See [details](https://www.alibabacloud.com/help/en/microservices-engine/latest/api-doc-mse-2019-05-31-api-doc-createcluster)
        """
        return pulumi.get(self, "cluster_version")

    @cluster_version.setter
    def cluster_version(self, value: pulumi.Input[str]):
        pulumi.set(self, "cluster_version", value)

    @property
    @pulumi.getter(name="instanceCount")
    def instance_count(self) -> pulumi.Input[int]:
        """
        The count of instance. **NOTE:** From version 1.188.0, `instance_count` can be modified.
        """
        return pulumi.get(self, "instance_count")

    @instance_count.setter
    def instance_count(self, value: pulumi.Input[int]):
        pulumi.set(self, "instance_count", value)

    @property
    @pulumi.getter(name="netType")
    def net_type(self) -> pulumi.Input[str]:
        """
        The type of network. Valid values: "privatenet" and "pubnet".
        """
        return pulumi.get(self, "net_type")

    @net_type.setter
    def net_type(self, value: pulumi.Input[str]):
        pulumi.set(self, "net_type", value)

    @property
    @pulumi.getter(name="pubNetworkFlow")
    def pub_network_flow(self) -> pulumi.Input[str]:
        """
        The public network bandwidth. `0` means no access to the public network.
        """
        return pulumi.get(self, "pub_network_flow")

    @pub_network_flow.setter
    def pub_network_flow(self, value: pulumi.Input[str]):
        pulumi.set(self, "pub_network_flow", value)

    @property
    @pulumi.getter(name="aclEntryLists")
    def acl_entry_lists(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[str]]]]:
        """
        The whitelist. **NOTE:** This attribute is invalid when the value of `pub_network_flow` is `0` and the value of `net_type` is `privatenet`.
        """
        return pulumi.get(self, "acl_entry_lists")

    @acl_entry_lists.setter
    def acl_entry_lists(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]]):
        pulumi.set(self, "acl_entry_lists", value)

    @property
    @pulumi.getter(name="clusterAliasName")
    def cluster_alias_name(self) -> Optional[pulumi.Input[str]]:
        """
        The alias of MSE Cluster.
        """
        return pulumi.get(self, "cluster_alias_name")

    @cluster_alias_name.setter
    def cluster_alias_name(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "cluster_alias_name", value)

    @property
    @pulumi.getter(name="connectionType")
    def connection_type(self) -> Optional[pulumi.Input[str]]:
        """
        The connection type. Valid values: `slb`.
        """
        return pulumi.get(self, "connection_type")

    @connection_type.setter
    def connection_type(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "connection_type", value)

    @property
    @pulumi.getter(name="diskType")
    def disk_type(self) -> Optional[pulumi.Input[str]]:
        """
        The type of Disk.
        """
        return pulumi.get(self, "disk_type")

    @disk_type.setter
    def disk_type(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "disk_type", value)

    @property
    @pulumi.getter(name="mseVersion")
    def mse_version(self) -> Optional[pulumi.Input[str]]:
        """
        The version of MSE. Valid values: `mse_dev` or `mse_pro`.
        """
        return pulumi.get(self, "mse_version")

    @mse_version.setter
    def mse_version(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "mse_version", value)

    @property
    @pulumi.getter(name="privateSlbSpecification")
    def private_slb_specification(self) -> Optional[pulumi.Input[str]]:
        """
        The specification of private network SLB.
        """
        return pulumi.get(self, "private_slb_specification")

    @private_slb_specification.setter
    def private_slb_specification(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "private_slb_specification", value)

    @property
    @pulumi.getter(name="pubSlbSpecification")
    def pub_slb_specification(self) -> Optional[pulumi.Input[str]]:
        """
        The specification of public network SLB.
        """
        return pulumi.get(self, "pub_slb_specification")

    @pub_slb_specification.setter
    def pub_slb_specification(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "pub_slb_specification", value)

    @property
    @pulumi.getter(name="requestPars")
    def request_pars(self) -> Optional[pulumi.Input[str]]:
        """
        The extended request parameters in the JSON format.
        """
        return pulumi.get(self, "request_pars")

    @request_pars.setter
    def request_pars(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "request_pars", value)

    @property
    @pulumi.getter(name="vpcId")
    def vpc_id(self) -> Optional[pulumi.Input[str]]:
        """
        The id of the VPC.
        """
        return pulumi.get(self, "vpc_id")

    @vpc_id.setter
    def vpc_id(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "vpc_id", value)

    @property
    @pulumi.getter(name="vswitchId")
    def vswitch_id(self) -> Optional[pulumi.Input[str]]:
        """
        The id of VSwitch.
        """
        return pulumi.get(self, "vswitch_id")

    @vswitch_id.setter
    def vswitch_id(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "vswitch_id", value)


@pulumi.input_type
class _ClusterState:
    def __init__(__self__, *,
                 acl_entry_lists: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None,
                 app_version: Optional[pulumi.Input[str]] = None,
                 cluster_alias_name: Optional[pulumi.Input[str]] = None,
                 cluster_id: Optional[pulumi.Input[str]] = None,
                 cluster_specification: Optional[pulumi.Input[str]] = None,
                 cluster_type: Optional[pulumi.Input[str]] = None,
                 cluster_version: Optional[pulumi.Input[str]] = None,
                 connection_type: Optional[pulumi.Input[str]] = None,
                 disk_type: Optional[pulumi.Input[str]] = None,
                 instance_count: Optional[pulumi.Input[int]] = None,
                 mse_version: Optional[pulumi.Input[str]] = None,
                 net_type: Optional[pulumi.Input[str]] = None,
                 private_slb_specification: Optional[pulumi.Input[str]] = None,
                 pub_network_flow: Optional[pulumi.Input[str]] = None,
                 pub_slb_specification: Optional[pulumi.Input[str]] = None,
                 request_pars: Optional[pulumi.Input[str]] = None,
                 status: Optional[pulumi.Input[str]] = None,
                 vpc_id: Optional[pulumi.Input[str]] = None,
                 vswitch_id: Optional[pulumi.Input[str]] = None):
        """
        Input properties used for looking up and filtering Cluster resources.
        :param pulumi.Input[Sequence[pulumi.Input[str]]] acl_entry_lists: The whitelist. **NOTE:** This attribute is invalid when the value of `pub_network_flow` is `0` and the value of `net_type` is `privatenet`.
        :param pulumi.Input[str] app_version: (Available in v1.205.0+) The application version.
        :param pulumi.Input[str] cluster_alias_name: The alias of MSE Cluster.
        :param pulumi.Input[str] cluster_id: (Available in v1.162.0+) The id of Cluster.
        :param pulumi.Input[str] cluster_specification: The engine specification of MSE Cluster. **NOTE:** From version 1.188.0, `cluster_specification` can be modified. Valid values:
        :param pulumi.Input[str] cluster_type: The type of MSE Cluster.
        :param pulumi.Input[str] cluster_version: The version of MSE Cluster. See [details](https://www.alibabacloud.com/help/en/microservices-engine/latest/api-doc-mse-2019-05-31-api-doc-createcluster)
        :param pulumi.Input[str] connection_type: The connection type. Valid values: `slb`.
        :param pulumi.Input[str] disk_type: The type of Disk.
        :param pulumi.Input[int] instance_count: The count of instance. **NOTE:** From version 1.188.0, `instance_count` can be modified.
        :param pulumi.Input[str] mse_version: The version of MSE. Valid values: `mse_dev` or `mse_pro`.
        :param pulumi.Input[str] net_type: The type of network. Valid values: "privatenet" and "pubnet".
        :param pulumi.Input[str] private_slb_specification: The specification of private network SLB.
        :param pulumi.Input[str] pub_network_flow: The public network bandwidth. `0` means no access to the public network.
        :param pulumi.Input[str] pub_slb_specification: The specification of public network SLB.
        :param pulumi.Input[str] request_pars: The extended request parameters in the JSON format.
        :param pulumi.Input[str] status: The status of MSE Cluster.
        :param pulumi.Input[str] vpc_id: The id of the VPC.
        :param pulumi.Input[str] vswitch_id: The id of VSwitch.
        """
        if acl_entry_lists is not None:
            pulumi.set(__self__, "acl_entry_lists", acl_entry_lists)
        if app_version is not None:
            pulumi.set(__self__, "app_version", app_version)
        if cluster_alias_name is not None:
            pulumi.set(__self__, "cluster_alias_name", cluster_alias_name)
        if cluster_id is not None:
            pulumi.set(__self__, "cluster_id", cluster_id)
        if cluster_specification is not None:
            pulumi.set(__self__, "cluster_specification", cluster_specification)
        if cluster_type is not None:
            pulumi.set(__self__, "cluster_type", cluster_type)
        if cluster_version is not None:
            pulumi.set(__self__, "cluster_version", cluster_version)
        if connection_type is not None:
            pulumi.set(__self__, "connection_type", connection_type)
        if disk_type is not None:
            pulumi.set(__self__, "disk_type", disk_type)
        if instance_count is not None:
            pulumi.set(__self__, "instance_count", instance_count)
        if mse_version is not None:
            pulumi.set(__self__, "mse_version", mse_version)
        if net_type is not None:
            pulumi.set(__self__, "net_type", net_type)
        if private_slb_specification is not None:
            pulumi.set(__self__, "private_slb_specification", private_slb_specification)
        if pub_network_flow is not None:
            pulumi.set(__self__, "pub_network_flow", pub_network_flow)
        if pub_slb_specification is not None:
            pulumi.set(__self__, "pub_slb_specification", pub_slb_specification)
        if request_pars is not None:
            pulumi.set(__self__, "request_pars", request_pars)
        if status is not None:
            pulumi.set(__self__, "status", status)
        if vpc_id is not None:
            pulumi.set(__self__, "vpc_id", vpc_id)
        if vswitch_id is not None:
            pulumi.set(__self__, "vswitch_id", vswitch_id)

    @property
    @pulumi.getter(name="aclEntryLists")
    def acl_entry_lists(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[str]]]]:
        """
        The whitelist. **NOTE:** This attribute is invalid when the value of `pub_network_flow` is `0` and the value of `net_type` is `privatenet`.
        """
        return pulumi.get(self, "acl_entry_lists")

    @acl_entry_lists.setter
    def acl_entry_lists(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]]):
        pulumi.set(self, "acl_entry_lists", value)

    @property
    @pulumi.getter(name="appVersion")
    def app_version(self) -> Optional[pulumi.Input[str]]:
        """
        (Available in v1.205.0+) The application version.
        """
        return pulumi.get(self, "app_version")

    @app_version.setter
    def app_version(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "app_version", value)

    @property
    @pulumi.getter(name="clusterAliasName")
    def cluster_alias_name(self) -> Optional[pulumi.Input[str]]:
        """
        The alias of MSE Cluster.
        """
        return pulumi.get(self, "cluster_alias_name")

    @cluster_alias_name.setter
    def cluster_alias_name(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "cluster_alias_name", value)

    @property
    @pulumi.getter(name="clusterId")
    def cluster_id(self) -> Optional[pulumi.Input[str]]:
        """
        (Available in v1.162.0+) The id of Cluster.
        """
        return pulumi.get(self, "cluster_id")

    @cluster_id.setter
    def cluster_id(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "cluster_id", value)

    @property
    @pulumi.getter(name="clusterSpecification")
    def cluster_specification(self) -> Optional[pulumi.Input[str]]:
        """
        The engine specification of MSE Cluster. **NOTE:** From version 1.188.0, `cluster_specification` can be modified. Valid values:
        """
        return pulumi.get(self, "cluster_specification")

    @cluster_specification.setter
    def cluster_specification(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "cluster_specification", value)

    @property
    @pulumi.getter(name="clusterType")
    def cluster_type(self) -> Optional[pulumi.Input[str]]:
        """
        The type of MSE Cluster.
        """
        return pulumi.get(self, "cluster_type")

    @cluster_type.setter
    def cluster_type(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "cluster_type", value)

    @property
    @pulumi.getter(name="clusterVersion")
    def cluster_version(self) -> Optional[pulumi.Input[str]]:
        """
        The version of MSE Cluster. See [details](https://www.alibabacloud.com/help/en/microservices-engine/latest/api-doc-mse-2019-05-31-api-doc-createcluster)
        """
        return pulumi.get(self, "cluster_version")

    @cluster_version.setter
    def cluster_version(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "cluster_version", value)

    @property
    @pulumi.getter(name="connectionType")
    def connection_type(self) -> Optional[pulumi.Input[str]]:
        """
        The connection type. Valid values: `slb`.
        """
        return pulumi.get(self, "connection_type")

    @connection_type.setter
    def connection_type(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "connection_type", value)

    @property
    @pulumi.getter(name="diskType")
    def disk_type(self) -> Optional[pulumi.Input[str]]:
        """
        The type of Disk.
        """
        return pulumi.get(self, "disk_type")

    @disk_type.setter
    def disk_type(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "disk_type", value)

    @property
    @pulumi.getter(name="instanceCount")
    def instance_count(self) -> Optional[pulumi.Input[int]]:
        """
        The count of instance. **NOTE:** From version 1.188.0, `instance_count` can be modified.
        """
        return pulumi.get(self, "instance_count")

    @instance_count.setter
    def instance_count(self, value: Optional[pulumi.Input[int]]):
        pulumi.set(self, "instance_count", value)

    @property
    @pulumi.getter(name="mseVersion")
    def mse_version(self) -> Optional[pulumi.Input[str]]:
        """
        The version of MSE. Valid values: `mse_dev` or `mse_pro`.
        """
        return pulumi.get(self, "mse_version")

    @mse_version.setter
    def mse_version(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "mse_version", value)

    @property
    @pulumi.getter(name="netType")
    def net_type(self) -> Optional[pulumi.Input[str]]:
        """
        The type of network. Valid values: "privatenet" and "pubnet".
        """
        return pulumi.get(self, "net_type")

    @net_type.setter
    def net_type(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "net_type", value)

    @property
    @pulumi.getter(name="privateSlbSpecification")
    def private_slb_specification(self) -> Optional[pulumi.Input[str]]:
        """
        The specification of private network SLB.
        """
        return pulumi.get(self, "private_slb_specification")

    @private_slb_specification.setter
    def private_slb_specification(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "private_slb_specification", value)

    @property
    @pulumi.getter(name="pubNetworkFlow")
    def pub_network_flow(self) -> Optional[pulumi.Input[str]]:
        """
        The public network bandwidth. `0` means no access to the public network.
        """
        return pulumi.get(self, "pub_network_flow")

    @pub_network_flow.setter
    def pub_network_flow(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "pub_network_flow", value)

    @property
    @pulumi.getter(name="pubSlbSpecification")
    def pub_slb_specification(self) -> Optional[pulumi.Input[str]]:
        """
        The specification of public network SLB.
        """
        return pulumi.get(self, "pub_slb_specification")

    @pub_slb_specification.setter
    def pub_slb_specification(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "pub_slb_specification", value)

    @property
    @pulumi.getter(name="requestPars")
    def request_pars(self) -> Optional[pulumi.Input[str]]:
        """
        The extended request parameters in the JSON format.
        """
        return pulumi.get(self, "request_pars")

    @request_pars.setter
    def request_pars(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "request_pars", value)

    @property
    @pulumi.getter
    def status(self) -> Optional[pulumi.Input[str]]:
        """
        The status of MSE Cluster.
        """
        return pulumi.get(self, "status")

    @status.setter
    def status(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "status", value)

    @property
    @pulumi.getter(name="vpcId")
    def vpc_id(self) -> Optional[pulumi.Input[str]]:
        """
        The id of the VPC.
        """
        return pulumi.get(self, "vpc_id")

    @vpc_id.setter
    def vpc_id(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "vpc_id", value)

    @property
    @pulumi.getter(name="vswitchId")
    def vswitch_id(self) -> Optional[pulumi.Input[str]]:
        """
        The id of VSwitch.
        """
        return pulumi.get(self, "vswitch_id")

    @vswitch_id.setter
    def vswitch_id(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "vswitch_id", value)


class Cluster(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 acl_entry_lists: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None,
                 cluster_alias_name: Optional[pulumi.Input[str]] = None,
                 cluster_specification: Optional[pulumi.Input[str]] = None,
                 cluster_type: Optional[pulumi.Input[str]] = None,
                 cluster_version: Optional[pulumi.Input[str]] = None,
                 connection_type: Optional[pulumi.Input[str]] = None,
                 disk_type: Optional[pulumi.Input[str]] = None,
                 instance_count: Optional[pulumi.Input[int]] = None,
                 mse_version: Optional[pulumi.Input[str]] = None,
                 net_type: Optional[pulumi.Input[str]] = None,
                 private_slb_specification: Optional[pulumi.Input[str]] = None,
                 pub_network_flow: Optional[pulumi.Input[str]] = None,
                 pub_slb_specification: Optional[pulumi.Input[str]] = None,
                 request_pars: Optional[pulumi.Input[str]] = None,
                 vpc_id: Optional[pulumi.Input[str]] = None,
                 vswitch_id: Optional[pulumi.Input[str]] = None,
                 __props__=None):
        """
        Provides a MSE Cluster resource. It is a one-stop microservice platform for the industry's mainstream open source microservice frameworks Spring Cloud and Dubbo, providing governance center, managed registry and managed configuration center.

        > **NOTE:** Available in 1.94.0+.

        ## Example Usage

        ```python
        import pulumi
        import pulumi_alicloud as alicloud

        example_zones = alicloud.get_zones(available_resource_creation="VSwitch")
        example_network = alicloud.vpc.Network("exampleNetwork",
            vpc_name="terraform-example",
            cidr_block="172.17.3.0/24")
        example_switch = alicloud.vpc.Switch("exampleSwitch",
            vswitch_name="terraform-example",
            cidr_block="172.17.3.0/24",
            vpc_id=example_network.id,
            zone_id=example_zones.zones[0].id)
        example_cluster = alicloud.mse.Cluster("exampleCluster",
            cluster_specification="MSE_SC_1_2_60_c",
            cluster_type="Nacos-Ans",
            cluster_version="NACOS_2_0_0",
            instance_count=1,
            net_type="privatenet",
            pub_network_flow="1",
            connection_type="slb",
            cluster_alias_name="terraform-example",
            mse_version="mse_dev",
            vswitch_id=example_switch.id,
            vpc_id=example_network.id)
        ```

        ## Import

        MSE Cluster can be imported using the id, e.g.

        ```sh
         $ pulumi import alicloud:mse/cluster:Cluster example mse-cn-0d9xxxx
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[Sequence[pulumi.Input[str]]] acl_entry_lists: The whitelist. **NOTE:** This attribute is invalid when the value of `pub_network_flow` is `0` and the value of `net_type` is `privatenet`.
        :param pulumi.Input[str] cluster_alias_name: The alias of MSE Cluster.
        :param pulumi.Input[str] cluster_specification: The engine specification of MSE Cluster. **NOTE:** From version 1.188.0, `cluster_specification` can be modified. Valid values:
        :param pulumi.Input[str] cluster_type: The type of MSE Cluster.
        :param pulumi.Input[str] cluster_version: The version of MSE Cluster. See [details](https://www.alibabacloud.com/help/en/microservices-engine/latest/api-doc-mse-2019-05-31-api-doc-createcluster)
        :param pulumi.Input[str] connection_type: The connection type. Valid values: `slb`.
        :param pulumi.Input[str] disk_type: The type of Disk.
        :param pulumi.Input[int] instance_count: The count of instance. **NOTE:** From version 1.188.0, `instance_count` can be modified.
        :param pulumi.Input[str] mse_version: The version of MSE. Valid values: `mse_dev` or `mse_pro`.
        :param pulumi.Input[str] net_type: The type of network. Valid values: "privatenet" and "pubnet".
        :param pulumi.Input[str] private_slb_specification: The specification of private network SLB.
        :param pulumi.Input[str] pub_network_flow: The public network bandwidth. `0` means no access to the public network.
        :param pulumi.Input[str] pub_slb_specification: The specification of public network SLB.
        :param pulumi.Input[str] request_pars: The extended request parameters in the JSON format.
        :param pulumi.Input[str] vpc_id: The id of the VPC.
        :param pulumi.Input[str] vswitch_id: The id of VSwitch.
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: ClusterArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        Provides a MSE Cluster resource. It is a one-stop microservice platform for the industry's mainstream open source microservice frameworks Spring Cloud and Dubbo, providing governance center, managed registry and managed configuration center.

        > **NOTE:** Available in 1.94.0+.

        ## Example Usage

        ```python
        import pulumi
        import pulumi_alicloud as alicloud

        example_zones = alicloud.get_zones(available_resource_creation="VSwitch")
        example_network = alicloud.vpc.Network("exampleNetwork",
            vpc_name="terraform-example",
            cidr_block="172.17.3.0/24")
        example_switch = alicloud.vpc.Switch("exampleSwitch",
            vswitch_name="terraform-example",
            cidr_block="172.17.3.0/24",
            vpc_id=example_network.id,
            zone_id=example_zones.zones[0].id)
        example_cluster = alicloud.mse.Cluster("exampleCluster",
            cluster_specification="MSE_SC_1_2_60_c",
            cluster_type="Nacos-Ans",
            cluster_version="NACOS_2_0_0",
            instance_count=1,
            net_type="privatenet",
            pub_network_flow="1",
            connection_type="slb",
            cluster_alias_name="terraform-example",
            mse_version="mse_dev",
            vswitch_id=example_switch.id,
            vpc_id=example_network.id)
        ```

        ## Import

        MSE Cluster can be imported using the id, e.g.

        ```sh
         $ pulumi import alicloud:mse/cluster:Cluster example mse-cn-0d9xxxx
        ```

        :param str resource_name: The name of the resource.
        :param ClusterArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(ClusterArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 acl_entry_lists: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None,
                 cluster_alias_name: Optional[pulumi.Input[str]] = None,
                 cluster_specification: Optional[pulumi.Input[str]] = None,
                 cluster_type: Optional[pulumi.Input[str]] = None,
                 cluster_version: Optional[pulumi.Input[str]] = None,
                 connection_type: Optional[pulumi.Input[str]] = None,
                 disk_type: Optional[pulumi.Input[str]] = None,
                 instance_count: Optional[pulumi.Input[int]] = None,
                 mse_version: Optional[pulumi.Input[str]] = None,
                 net_type: Optional[pulumi.Input[str]] = None,
                 private_slb_specification: Optional[pulumi.Input[str]] = None,
                 pub_network_flow: Optional[pulumi.Input[str]] = None,
                 pub_slb_specification: Optional[pulumi.Input[str]] = None,
                 request_pars: Optional[pulumi.Input[str]] = None,
                 vpc_id: Optional[pulumi.Input[str]] = None,
                 vswitch_id: Optional[pulumi.Input[str]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = ClusterArgs.__new__(ClusterArgs)

            __props__.__dict__["acl_entry_lists"] = acl_entry_lists
            __props__.__dict__["cluster_alias_name"] = cluster_alias_name
            if cluster_specification is None and not opts.urn:
                raise TypeError("Missing required property 'cluster_specification'")
            __props__.__dict__["cluster_specification"] = cluster_specification
            if cluster_type is None and not opts.urn:
                raise TypeError("Missing required property 'cluster_type'")
            __props__.__dict__["cluster_type"] = cluster_type
            if cluster_version is None and not opts.urn:
                raise TypeError("Missing required property 'cluster_version'")
            __props__.__dict__["cluster_version"] = cluster_version
            __props__.__dict__["connection_type"] = connection_type
            __props__.__dict__["disk_type"] = disk_type
            if instance_count is None and not opts.urn:
                raise TypeError("Missing required property 'instance_count'")
            __props__.__dict__["instance_count"] = instance_count
            __props__.__dict__["mse_version"] = mse_version
            if net_type is None and not opts.urn:
                raise TypeError("Missing required property 'net_type'")
            __props__.__dict__["net_type"] = net_type
            __props__.__dict__["private_slb_specification"] = private_slb_specification
            if pub_network_flow is None and not opts.urn:
                raise TypeError("Missing required property 'pub_network_flow'")
            __props__.__dict__["pub_network_flow"] = pub_network_flow
            __props__.__dict__["pub_slb_specification"] = pub_slb_specification
            __props__.__dict__["request_pars"] = request_pars
            __props__.__dict__["vpc_id"] = vpc_id
            __props__.__dict__["vswitch_id"] = vswitch_id
            __props__.__dict__["app_version"] = None
            __props__.__dict__["cluster_id"] = None
            __props__.__dict__["status"] = None
        super(Cluster, __self__).__init__(
            'alicloud:mse/cluster:Cluster',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            acl_entry_lists: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None,
            app_version: Optional[pulumi.Input[str]] = None,
            cluster_alias_name: Optional[pulumi.Input[str]] = None,
            cluster_id: Optional[pulumi.Input[str]] = None,
            cluster_specification: Optional[pulumi.Input[str]] = None,
            cluster_type: Optional[pulumi.Input[str]] = None,
            cluster_version: Optional[pulumi.Input[str]] = None,
            connection_type: Optional[pulumi.Input[str]] = None,
            disk_type: Optional[pulumi.Input[str]] = None,
            instance_count: Optional[pulumi.Input[int]] = None,
            mse_version: Optional[pulumi.Input[str]] = None,
            net_type: Optional[pulumi.Input[str]] = None,
            private_slb_specification: Optional[pulumi.Input[str]] = None,
            pub_network_flow: Optional[pulumi.Input[str]] = None,
            pub_slb_specification: Optional[pulumi.Input[str]] = None,
            request_pars: Optional[pulumi.Input[str]] = None,
            status: Optional[pulumi.Input[str]] = None,
            vpc_id: Optional[pulumi.Input[str]] = None,
            vswitch_id: Optional[pulumi.Input[str]] = None) -> 'Cluster':
        """
        Get an existing Cluster resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[Sequence[pulumi.Input[str]]] acl_entry_lists: The whitelist. **NOTE:** This attribute is invalid when the value of `pub_network_flow` is `0` and the value of `net_type` is `privatenet`.
        :param pulumi.Input[str] app_version: (Available in v1.205.0+) The application version.
        :param pulumi.Input[str] cluster_alias_name: The alias of MSE Cluster.
        :param pulumi.Input[str] cluster_id: (Available in v1.162.0+) The id of Cluster.
        :param pulumi.Input[str] cluster_specification: The engine specification of MSE Cluster. **NOTE:** From version 1.188.0, `cluster_specification` can be modified. Valid values:
        :param pulumi.Input[str] cluster_type: The type of MSE Cluster.
        :param pulumi.Input[str] cluster_version: The version of MSE Cluster. See [details](https://www.alibabacloud.com/help/en/microservices-engine/latest/api-doc-mse-2019-05-31-api-doc-createcluster)
        :param pulumi.Input[str] connection_type: The connection type. Valid values: `slb`.
        :param pulumi.Input[str] disk_type: The type of Disk.
        :param pulumi.Input[int] instance_count: The count of instance. **NOTE:** From version 1.188.0, `instance_count` can be modified.
        :param pulumi.Input[str] mse_version: The version of MSE. Valid values: `mse_dev` or `mse_pro`.
        :param pulumi.Input[str] net_type: The type of network. Valid values: "privatenet" and "pubnet".
        :param pulumi.Input[str] private_slb_specification: The specification of private network SLB.
        :param pulumi.Input[str] pub_network_flow: The public network bandwidth. `0` means no access to the public network.
        :param pulumi.Input[str] pub_slb_specification: The specification of public network SLB.
        :param pulumi.Input[str] request_pars: The extended request parameters in the JSON format.
        :param pulumi.Input[str] status: The status of MSE Cluster.
        :param pulumi.Input[str] vpc_id: The id of the VPC.
        :param pulumi.Input[str] vswitch_id: The id of VSwitch.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _ClusterState.__new__(_ClusterState)

        __props__.__dict__["acl_entry_lists"] = acl_entry_lists
        __props__.__dict__["app_version"] = app_version
        __props__.__dict__["cluster_alias_name"] = cluster_alias_name
        __props__.__dict__["cluster_id"] = cluster_id
        __props__.__dict__["cluster_specification"] = cluster_specification
        __props__.__dict__["cluster_type"] = cluster_type
        __props__.__dict__["cluster_version"] = cluster_version
        __props__.__dict__["connection_type"] = connection_type
        __props__.__dict__["disk_type"] = disk_type
        __props__.__dict__["instance_count"] = instance_count
        __props__.__dict__["mse_version"] = mse_version
        __props__.__dict__["net_type"] = net_type
        __props__.__dict__["private_slb_specification"] = private_slb_specification
        __props__.__dict__["pub_network_flow"] = pub_network_flow
        __props__.__dict__["pub_slb_specification"] = pub_slb_specification
        __props__.__dict__["request_pars"] = request_pars
        __props__.__dict__["status"] = status
        __props__.__dict__["vpc_id"] = vpc_id
        __props__.__dict__["vswitch_id"] = vswitch_id
        return Cluster(resource_name, opts=opts, __props__=__props__)

    @property
    @pulumi.getter(name="aclEntryLists")
    def acl_entry_lists(self) -> pulumi.Output[Optional[Sequence[str]]]:
        """
        The whitelist. **NOTE:** This attribute is invalid when the value of `pub_network_flow` is `0` and the value of `net_type` is `privatenet`.
        """
        return pulumi.get(self, "acl_entry_lists")

    @property
    @pulumi.getter(name="appVersion")
    def app_version(self) -> pulumi.Output[str]:
        """
        (Available in v1.205.0+) The application version.
        """
        return pulumi.get(self, "app_version")

    @property
    @pulumi.getter(name="clusterAliasName")
    def cluster_alias_name(self) -> pulumi.Output[Optional[str]]:
        """
        The alias of MSE Cluster.
        """
        return pulumi.get(self, "cluster_alias_name")

    @property
    @pulumi.getter(name="clusterId")
    def cluster_id(self) -> pulumi.Output[str]:
        """
        (Available in v1.162.0+) The id of Cluster.
        """
        return pulumi.get(self, "cluster_id")

    @property
    @pulumi.getter(name="clusterSpecification")
    def cluster_specification(self) -> pulumi.Output[str]:
        """
        The engine specification of MSE Cluster. **NOTE:** From version 1.188.0, `cluster_specification` can be modified. Valid values:
        """
        return pulumi.get(self, "cluster_specification")

    @property
    @pulumi.getter(name="clusterType")
    def cluster_type(self) -> pulumi.Output[str]:
        """
        The type of MSE Cluster.
        """
        return pulumi.get(self, "cluster_type")

    @property
    @pulumi.getter(name="clusterVersion")
    def cluster_version(self) -> pulumi.Output[str]:
        """
        The version of MSE Cluster. See [details](https://www.alibabacloud.com/help/en/microservices-engine/latest/api-doc-mse-2019-05-31-api-doc-createcluster)
        """
        return pulumi.get(self, "cluster_version")

    @property
    @pulumi.getter(name="connectionType")
    def connection_type(self) -> pulumi.Output[str]:
        """
        The connection type. Valid values: `slb`.
        """
        return pulumi.get(self, "connection_type")

    @property
    @pulumi.getter(name="diskType")
    def disk_type(self) -> pulumi.Output[Optional[str]]:
        """
        The type of Disk.
        """
        return pulumi.get(self, "disk_type")

    @property
    @pulumi.getter(name="instanceCount")
    def instance_count(self) -> pulumi.Output[int]:
        """
        The count of instance. **NOTE:** From version 1.188.0, `instance_count` can be modified.
        """
        return pulumi.get(self, "instance_count")

    @property
    @pulumi.getter(name="mseVersion")
    def mse_version(self) -> pulumi.Output[str]:
        """
        The version of MSE. Valid values: `mse_dev` or `mse_pro`.
        """
        return pulumi.get(self, "mse_version")

    @property
    @pulumi.getter(name="netType")
    def net_type(self) -> pulumi.Output[str]:
        """
        The type of network. Valid values: "privatenet" and "pubnet".
        """
        return pulumi.get(self, "net_type")

    @property
    @pulumi.getter(name="privateSlbSpecification")
    def private_slb_specification(self) -> pulumi.Output[Optional[str]]:
        """
        The specification of private network SLB.
        """
        return pulumi.get(self, "private_slb_specification")

    @property
    @pulumi.getter(name="pubNetworkFlow")
    def pub_network_flow(self) -> pulumi.Output[str]:
        """
        The public network bandwidth. `0` means no access to the public network.
        """
        return pulumi.get(self, "pub_network_flow")

    @property
    @pulumi.getter(name="pubSlbSpecification")
    def pub_slb_specification(self) -> pulumi.Output[Optional[str]]:
        """
        The specification of public network SLB.
        """
        return pulumi.get(self, "pub_slb_specification")

    @property
    @pulumi.getter(name="requestPars")
    def request_pars(self) -> pulumi.Output[Optional[str]]:
        """
        The extended request parameters in the JSON format.
        """
        return pulumi.get(self, "request_pars")

    @property
    @pulumi.getter
    def status(self) -> pulumi.Output[str]:
        """
        The status of MSE Cluster.
        """
        return pulumi.get(self, "status")

    @property
    @pulumi.getter(name="vpcId")
    def vpc_id(self) -> pulumi.Output[str]:
        """
        The id of the VPC.
        """
        return pulumi.get(self, "vpc_id")

    @property
    @pulumi.getter(name="vswitchId")
    def vswitch_id(self) -> pulumi.Output[Optional[str]]:
        """
        The id of VSwitch.
        """
        return pulumi.get(self, "vswitch_id")




# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
from .. import _utilities

__all__ = ['ServiceLinkedRoleArgs', 'ServiceLinkedRole']

@pulumi.input_type
class ServiceLinkedRoleArgs:
    def __init__(__self__, *,
                 service_name: pulumi.Input[str],
                 custom_suffix: Optional[pulumi.Input[str]] = None,
                 description: Optional[pulumi.Input[str]] = None):
        """
        The set of arguments for constructing a ServiceLinkedRole resource.
        :param pulumi.Input[str] service_name: The service name. For more information about the service name, see [Cloud services that support service linked roles](https://www.alibabacloud.com/help/en/doc-detail/160674.htm)
        :param pulumi.Input[str] custom_suffix: The suffix of the role name. Only a few service linked roles support custom suffixes. The role name (including its suffix) must be 1 to 64 characters in length and can contain letters, digits, periods (.), and hyphens (-). For example, if the suffix is Example, the role name is ServiceLinkedRoleName_Example.
        :param pulumi.Input[str] description: The description of the service linked role.  This parameter must be specified for only the service linked roles that support custom suffixes. Otherwise, the preset value is used and cannot be modified. The description must be 1 to 1,024 characters in length.
        """
        pulumi.set(__self__, "service_name", service_name)
        if custom_suffix is not None:
            pulumi.set(__self__, "custom_suffix", custom_suffix)
        if description is not None:
            pulumi.set(__self__, "description", description)

    @property
    @pulumi.getter(name="serviceName")
    def service_name(self) -> pulumi.Input[str]:
        """
        The service name. For more information about the service name, see [Cloud services that support service linked roles](https://www.alibabacloud.com/help/en/doc-detail/160674.htm)
        """
        return pulumi.get(self, "service_name")

    @service_name.setter
    def service_name(self, value: pulumi.Input[str]):
        pulumi.set(self, "service_name", value)

    @property
    @pulumi.getter(name="customSuffix")
    def custom_suffix(self) -> Optional[pulumi.Input[str]]:
        """
        The suffix of the role name. Only a few service linked roles support custom suffixes. The role name (including its suffix) must be 1 to 64 characters in length and can contain letters, digits, periods (.), and hyphens (-). For example, if the suffix is Example, the role name is ServiceLinkedRoleName_Example.
        """
        return pulumi.get(self, "custom_suffix")

    @custom_suffix.setter
    def custom_suffix(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "custom_suffix", value)

    @property
    @pulumi.getter
    def description(self) -> Optional[pulumi.Input[str]]:
        """
        The description of the service linked role.  This parameter must be specified for only the service linked roles that support custom suffixes. Otherwise, the preset value is used and cannot be modified. The description must be 1 to 1,024 characters in length.
        """
        return pulumi.get(self, "description")

    @description.setter
    def description(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "description", value)


@pulumi.input_type
class _ServiceLinkedRoleState:
    def __init__(__self__, *,
                 arn: Optional[pulumi.Input[str]] = None,
                 custom_suffix: Optional[pulumi.Input[str]] = None,
                 description: Optional[pulumi.Input[str]] = None,
                 role_id: Optional[pulumi.Input[str]] = None,
                 role_name: Optional[pulumi.Input[str]] = None,
                 service_name: Optional[pulumi.Input[str]] = None):
        """
        Input properties used for looking up and filtering ServiceLinkedRole resources.
        :param pulumi.Input[str] arn: The Alibaba Cloud Resource Name (ARN) of the role.
        :param pulumi.Input[str] custom_suffix: The suffix of the role name. Only a few service linked roles support custom suffixes. The role name (including its suffix) must be 1 to 64 characters in length and can contain letters, digits, periods (.), and hyphens (-). For example, if the suffix is Example, the role name is ServiceLinkedRoleName_Example.
        :param pulumi.Input[str] description: The description of the service linked role.  This parameter must be specified for only the service linked roles that support custom suffixes. Otherwise, the preset value is used and cannot be modified. The description must be 1 to 1,024 characters in length.
        :param pulumi.Input[str] role_id: The ID of the role.
        :param pulumi.Input[str] role_name: The name of the role.
        :param pulumi.Input[str] service_name: The service name. For more information about the service name, see [Cloud services that support service linked roles](https://www.alibabacloud.com/help/en/doc-detail/160674.htm)
        """
        if arn is not None:
            pulumi.set(__self__, "arn", arn)
        if custom_suffix is not None:
            pulumi.set(__self__, "custom_suffix", custom_suffix)
        if description is not None:
            pulumi.set(__self__, "description", description)
        if role_id is not None:
            pulumi.set(__self__, "role_id", role_id)
        if role_name is not None:
            pulumi.set(__self__, "role_name", role_name)
        if service_name is not None:
            pulumi.set(__self__, "service_name", service_name)

    @property
    @pulumi.getter
    def arn(self) -> Optional[pulumi.Input[str]]:
        """
        The Alibaba Cloud Resource Name (ARN) of the role.
        """
        return pulumi.get(self, "arn")

    @arn.setter
    def arn(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "arn", value)

    @property
    @pulumi.getter(name="customSuffix")
    def custom_suffix(self) -> Optional[pulumi.Input[str]]:
        """
        The suffix of the role name. Only a few service linked roles support custom suffixes. The role name (including its suffix) must be 1 to 64 characters in length and can contain letters, digits, periods (.), and hyphens (-). For example, if the suffix is Example, the role name is ServiceLinkedRoleName_Example.
        """
        return pulumi.get(self, "custom_suffix")

    @custom_suffix.setter
    def custom_suffix(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "custom_suffix", value)

    @property
    @pulumi.getter
    def description(self) -> Optional[pulumi.Input[str]]:
        """
        The description of the service linked role.  This parameter must be specified for only the service linked roles that support custom suffixes. Otherwise, the preset value is used and cannot be modified. The description must be 1 to 1,024 characters in length.
        """
        return pulumi.get(self, "description")

    @description.setter
    def description(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "description", value)

    @property
    @pulumi.getter(name="roleId")
    def role_id(self) -> Optional[pulumi.Input[str]]:
        """
        The ID of the role.
        """
        return pulumi.get(self, "role_id")

    @role_id.setter
    def role_id(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "role_id", value)

    @property
    @pulumi.getter(name="roleName")
    def role_name(self) -> Optional[pulumi.Input[str]]:
        """
        The name of the role.
        """
        return pulumi.get(self, "role_name")

    @role_name.setter
    def role_name(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "role_name", value)

    @property
    @pulumi.getter(name="serviceName")
    def service_name(self) -> Optional[pulumi.Input[str]]:
        """
        The service name. For more information about the service name, see [Cloud services that support service linked roles](https://www.alibabacloud.com/help/en/doc-detail/160674.htm)
        """
        return pulumi.get(self, "service_name")

    @service_name.setter
    def service_name(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "service_name", value)


class ServiceLinkedRole(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 custom_suffix: Optional[pulumi.Input[str]] = None,
                 description: Optional[pulumi.Input[str]] = None,
                 service_name: Optional[pulumi.Input[str]] = None,
                 __props__=None):
        """
        Provides a Resource Manager Service Linked Role.

        For information about Resource Manager Service Linked Role and how to use it, see [What is Service Linked Role.](https://www.alibabacloud.com/help/en/doc-detail/171226.htm).

        > **NOTE:** Available in v1.157.0+.

        ## Example Usage

        Basic Usage

        ```python
        import pulumi
        import pulumi_alicloud as alicloud

        default = alicloud.resourcemanager.ServiceLinkedRole("default", service_name="ops.elasticsearch.aliyuncs.com")
        ```

        ## Import

        Resource Manager Service Linked Role can be imported using the id, e.g.

        ```sh
         $ pulumi import alicloud:resourcemanager/serviceLinkedRole:ServiceLinkedRole default <service_name>:<role_name>
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[str] custom_suffix: The suffix of the role name. Only a few service linked roles support custom suffixes. The role name (including its suffix) must be 1 to 64 characters in length and can contain letters, digits, periods (.), and hyphens (-). For example, if the suffix is Example, the role name is ServiceLinkedRoleName_Example.
        :param pulumi.Input[str] description: The description of the service linked role.  This parameter must be specified for only the service linked roles that support custom suffixes. Otherwise, the preset value is used and cannot be modified. The description must be 1 to 1,024 characters in length.
        :param pulumi.Input[str] service_name: The service name. For more information about the service name, see [Cloud services that support service linked roles](https://www.alibabacloud.com/help/en/doc-detail/160674.htm)
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: ServiceLinkedRoleArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        Provides a Resource Manager Service Linked Role.

        For information about Resource Manager Service Linked Role and how to use it, see [What is Service Linked Role.](https://www.alibabacloud.com/help/en/doc-detail/171226.htm).

        > **NOTE:** Available in v1.157.0+.

        ## Example Usage

        Basic Usage

        ```python
        import pulumi
        import pulumi_alicloud as alicloud

        default = alicloud.resourcemanager.ServiceLinkedRole("default", service_name="ops.elasticsearch.aliyuncs.com")
        ```

        ## Import

        Resource Manager Service Linked Role can be imported using the id, e.g.

        ```sh
         $ pulumi import alicloud:resourcemanager/serviceLinkedRole:ServiceLinkedRole default <service_name>:<role_name>
        ```

        :param str resource_name: The name of the resource.
        :param ServiceLinkedRoleArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(ServiceLinkedRoleArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 custom_suffix: Optional[pulumi.Input[str]] = None,
                 description: Optional[pulumi.Input[str]] = None,
                 service_name: Optional[pulumi.Input[str]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = ServiceLinkedRoleArgs.__new__(ServiceLinkedRoleArgs)

            __props__.__dict__["custom_suffix"] = custom_suffix
            __props__.__dict__["description"] = description
            if service_name is None and not opts.urn:
                raise TypeError("Missing required property 'service_name'")
            __props__.__dict__["service_name"] = service_name
            __props__.__dict__["arn"] = None
            __props__.__dict__["role_id"] = None
            __props__.__dict__["role_name"] = None
        super(ServiceLinkedRole, __self__).__init__(
            'alicloud:resourcemanager/serviceLinkedRole:ServiceLinkedRole',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            arn: Optional[pulumi.Input[str]] = None,
            custom_suffix: Optional[pulumi.Input[str]] = None,
            description: Optional[pulumi.Input[str]] = None,
            role_id: Optional[pulumi.Input[str]] = None,
            role_name: Optional[pulumi.Input[str]] = None,
            service_name: Optional[pulumi.Input[str]] = None) -> 'ServiceLinkedRole':
        """
        Get an existing ServiceLinkedRole resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[str] arn: The Alibaba Cloud Resource Name (ARN) of the role.
        :param pulumi.Input[str] custom_suffix: The suffix of the role name. Only a few service linked roles support custom suffixes. The role name (including its suffix) must be 1 to 64 characters in length and can contain letters, digits, periods (.), and hyphens (-). For example, if the suffix is Example, the role name is ServiceLinkedRoleName_Example.
        :param pulumi.Input[str] description: The description of the service linked role.  This parameter must be specified for only the service linked roles that support custom suffixes. Otherwise, the preset value is used and cannot be modified. The description must be 1 to 1,024 characters in length.
        :param pulumi.Input[str] role_id: The ID of the role.
        :param pulumi.Input[str] role_name: The name of the role.
        :param pulumi.Input[str] service_name: The service name. For more information about the service name, see [Cloud services that support service linked roles](https://www.alibabacloud.com/help/en/doc-detail/160674.htm)
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _ServiceLinkedRoleState.__new__(_ServiceLinkedRoleState)

        __props__.__dict__["arn"] = arn
        __props__.__dict__["custom_suffix"] = custom_suffix
        __props__.__dict__["description"] = description
        __props__.__dict__["role_id"] = role_id
        __props__.__dict__["role_name"] = role_name
        __props__.__dict__["service_name"] = service_name
        return ServiceLinkedRole(resource_name, opts=opts, __props__=__props__)

    @property
    @pulumi.getter
    def arn(self) -> pulumi.Output[str]:
        """
        The Alibaba Cloud Resource Name (ARN) of the role.
        """
        return pulumi.get(self, "arn")

    @property
    @pulumi.getter(name="customSuffix")
    def custom_suffix(self) -> pulumi.Output[Optional[str]]:
        """
        The suffix of the role name. Only a few service linked roles support custom suffixes. The role name (including its suffix) must be 1 to 64 characters in length and can contain letters, digits, periods (.), and hyphens (-). For example, if the suffix is Example, the role name is ServiceLinkedRoleName_Example.
        """
        return pulumi.get(self, "custom_suffix")

    @property
    @pulumi.getter
    def description(self) -> pulumi.Output[Optional[str]]:
        """
        The description of the service linked role.  This parameter must be specified for only the service linked roles that support custom suffixes. Otherwise, the preset value is used and cannot be modified. The description must be 1 to 1,024 characters in length.
        """
        return pulumi.get(self, "description")

    @property
    @pulumi.getter(name="roleId")
    def role_id(self) -> pulumi.Output[str]:
        """
        The ID of the role.
        """
        return pulumi.get(self, "role_id")

    @property
    @pulumi.getter(name="roleName")
    def role_name(self) -> pulumi.Output[str]:
        """
        The name of the role.
        """
        return pulumi.get(self, "role_name")

    @property
    @pulumi.getter(name="serviceName")
    def service_name(self) -> pulumi.Output[str]:
        """
        The service name. For more information about the service name, see [Cloud services that support service linked roles](https://www.alibabacloud.com/help/en/doc-detail/160674.htm)
        """
        return pulumi.get(self, "service_name")

